@@ -32,6 +32,9 @@ import wx
 import obd_io #OBD2 funcs
 import os #os.environ
 
+import SpeedMeter as SM
+from math import pi, sqrt
+
 import threading
 import sys
 import serial
@@ -72,6 +75,7 @@ ID_HELP_ORDER = 510
 ID_HELP_ABOUT_Maemo = 511
 ID_HELP_VISIT_Maemo = 512
 
+
 # Define notification event for sensor result window
 EVT_RESULT_ID = 1000
 def EVT_RESULT(win, func,id):
@@ -117,8 +121,15 @@ class TestEvent(wx.PyEvent):
        self.SetEventType(EVT_TESTS_ID)
        self.data = data
 
-
-
+# Define notification event for dial result window
+EVT_DIAL_ID = 1004
+class DialEvent(wx.PyEvent):
+   """Simple event to carry arbitrary result data."""
+   def __init__(self, data):
+       """Init Dial Event."""
+       wx.PyEvent.__init__(self)
+       self.SetEventType(EVT_DIAL_ID)
+       self.data = data
        
 #defines notification event for debug tracewindow
 from debugEvent import *
@@ -144,7 +155,7 @@ class MyApp(wx.App):
             self._notify_window=_notify_window
             self._nb=_nb
             threading.Thread.__init__ ( self )
-        
+
 
         def initCommunication(self):
 
@@ -164,11 +175,10 @@ class MyApp(wx.App):
             self.supp1  = self.port.sensor(32)[1] #read supported PIDS2x
             self.supp2  = self.port.sensor(64)[1] #read supported PIDS3x
 
-            print "self.supp  " + (self.supp)
-            print "self.supp1 " + (self.supp1)
-            print "self.supp2 " + (self.supp2)
+            #print "self.supp  " + (self.supp)
+            #print "self.supp1 " + (self.supp1)
+            #print "self.supp2 " + (self.supp2)
 
-            #self.supp = self.supp+self.supp1
             self.supp = str(self.supp+self.supp1+self.supp2)
 
             print "self.sup f: " + self.supp
@@ -191,6 +201,8 @@ class MyApp(wx.App):
 
         def run(self):
             global btname
+
+
             wx.PostEvent(self._notify_window, StatusEvent([0,1,"Connecting...."]))
             try:
                self.initCommunication()
@@ -224,11 +236,13 @@ class MyApp(wx.App):
             prevstate=-1
             curstate=-1
 
-
-
             while self._notify_window.ThreadControl!=666:
+                wx.Yield()
                 prevstate=curstate
                 curstate=self._nb.GetSelection()
+                #print "curstate: "+str(curstate)
+                time.sleep(0.1)
+
                 if curstate==0: #show status tab
                   pass
                 elif curstate==1: #show tests tab
@@ -319,6 +333,29 @@ class MyApp(wx.App):
                          os.popen(log2)
                          pass
 
+#Gauge
+		elif curstate==4:
+
+			wx.Yield()
+			speedsensor=13
+			if self.active[speedsensor]:
+				s = self.port.sensor(speedsensor)
+				text=str(s[1])
+				l=len(text)
+				n=0
+				while n<(l-1):
+					if str(text[n]) == '#' :
+						text="kmh"+text[0:n]
+						break
+					n=n+1
+				wx.PostEvent(self._notify_window, DialEvent(text))
+			speedsensor=12
+			if self.active[speedsensor]:
+				s = self.port.sensor(speedsensor)
+				text="rpm"+str(s[1])
+				wx.PostEvent(self._notify_window, DialEvent(text))
+                   
+
                 else:
                  pass 
             self.stop()
@@ -465,7 +502,134 @@ class MyApp(wx.App):
         ####################################################################
         
         self.nb.AddPage(self.DTCpanel, "DTC")
-         
+
+
+    def build_dial_page(self):
+        HOFFSET_LIST=0 #offset from the top of panel (space for buttons)
+        Dialpanel = wx.Panel(self.nb, -1)
+        self.Dialpanel=Dialpanel
+        tID = wx.NewId()
+        self.dial_id = tID
+
+        # First SpeedMeter: We Use The Following Styles:
+        #
+        # SM_DRAW_HAND: We Want To Draw The Hand (Arrow) Indicator
+        # SM_DRAW_SECTORS: Full Sectors Will Be Drawn, To Indicate Different Intervals
+        # SM_DRAW_MIDDLE_TEXT: We Draw Some Text In The Center Of SpeedMeter
+        # SM_DRAW_SECONDARY_TICKS: We Draw Secondary (Intermediate) Ticks Between
+        #                          The Main Ticks (Intervals)
+
+
+        self.SpeedWindow1 = SM.SpeedMeter(Dialpanel,
+                                          extrastyle=SM.SM_DRAW_HAND |
+                                          SM.SM_DRAW_SECTORS |
+                                          SM.SM_DRAW_MIDDLE_TEXT |
+                                          SM.SM_DRAW_SECONDARY_TICKS
+                                          )
+
+        # Set The Region Of Existence Of SpeedMeter (Always In Radians!!!!)
+        self.SpeedWindow1.SetAngleRange(-pi/6, 7*pi/6)
+
+        # Create The Intervals That Will Divide Our SpeedMeter In Sectors        
+        intervals = range(0, 201, 20)
+        self.SpeedWindow1.SetIntervals(intervals)
+
+        # Assign The Same Colours To All Sectors (We Simulate A Car Control For Speed)
+        # Usually This Is Black
+        colours = [wx.BLACK]*10
+        self.SpeedWindow1.SetIntervalColours(colours)
+
+        # Assign The Ticks: Here They Are Simply The String Equivalent Of The Intervals
+
+        ticks = [str(interval) for interval in intervals]
+        self.SpeedWindow1.SetTicks(ticks)
+        # Set The Ticks/Tick Markers Colour
+        self.SpeedWindow1.SetTicksColour(wx.WHITE)
+        # We Want To Draw 5 Secondary Ticks Between The Principal Ticks
+        self.SpeedWindow1.SetNumberOfSecondaryTicks(5)
+
+        # Set The Font For The Ticks Markers
+        self.SpeedWindow1.SetTicksFont(wx.Font(10, wx.SWISS, wx.NORMAL, wx.NORMAL))
+                                       
+        # Set The Text In The Center Of SpeedMeter
+        self.SpeedWindow1.SetMiddleText("Km/h")
+        # Assign The Colour To The Center Text
+        self.SpeedWindow1.SetMiddleTextColour(wx.WHITE)
+        # Assign A Font To The Center Text
+        self.SpeedWindow1.SetMiddleTextFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
+
+        # Set The Colour For The Hand Indicator
+        self.SpeedWindow1.SetHandColour(wx.Colour(255, 50, 0))
+
+        # Do Not Draw The External (Container) Arc. Drawing The External Arc May
+        # Sometimes Create Uglier Controls. Try To Comment This Line And See It
+        # For Yourself!
+        self.SpeedWindow1.DrawExternalArc(False)        
+
+        # Set The Current Value For The SpeedMeter
+        self.SpeedWindow1.SetSpeedValue(6)
+
+
+        self.SpeedWindow5 = SM.SpeedMeter(Dialpanel,
+                                          extrastyle=SM.SM_DRAW_HAND |
+                                          SM.SM_DRAW_PARTIAL_SECTORS |
+                                          SM.SM_DRAW_SECONDARY_TICKS |
+                                          SM.SM_DRAW_MIDDLE_TEXT |
+                                          SM.SM_ROTATE_TEXT
+                                          )
+
+        # We Want To Simulate The Round Per Meter Control In A Car
+        self.SpeedWindow5.SetAngleRange(-pi/6, 7*pi/6)
+
+        intervals = range(0, 9)
+        self.SpeedWindow5.SetIntervals(intervals)
+
+        colours = [wx.BLACK]*6
+        colours.append(wx.Colour(255, 255, 0))
+        colours.append(wx.RED)
+        self.SpeedWindow5.SetIntervalColours(colours)
+
+        ticks = [str(interval) for interval in intervals]
+        self.SpeedWindow5.SetTicks(ticks)
+        self.SpeedWindow5.SetTicksColour(wx.WHITE)
+        self.SpeedWindow5.SetTicksFont(wx.Font(10, wx.SWISS, wx.NORMAL, wx.NORMAL))
+
+        self.SpeedWindow5.SetHandColour(wx.Colour(255, 50, 0))
+
+        self.SpeedWindow5.SetSpeedBackground(wx.SystemSettings_GetColour(0))        
+
+        self.SpeedWindow5.DrawExternalArc(False)
+
+        self.SpeedWindow5.SetShadowColour(wx.Colour(50, 50, 50))
+
+        self.SpeedWindow5.SetMiddleText("rpm")
+        self.SpeedWindow5.SetMiddleTextColour(wx.WHITE)
+        self.SpeedWindow5.SetMiddleTextFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
+        self.SpeedWindow5.SetSpeedBackground(wx.Colour(0, 0, 0)) 
+        
+        self.SpeedWindow5.SetSpeedValue(.2)
+        
+
+
+        ####################################################################
+        # This little bit of magic keeps the list the same size as the frame
+        def OnPSize(e, win = Dialpanel):
+            Dialpanel.SetSize(e.GetSize())
+            self.SpeedWindow1.SetSize(e.GetSize())
+            self.SpeedWindow5.SetSize(e.GetSize())
+
+            w,h = self.frame.GetClientSizeTuple()
+            self.SpeedWindow1.SetDimensions(0,HOFFSET_LIST+10, w/2 ,h )
+            self.SpeedWindow5.SetDimensions(400,HOFFSET_LIST+10, w/2 , h )
+
+
+        Dialpanel.Bind(wx.EVT_SIZE,OnPSize)
+        ####################################################################
+
+
+        self.nb.AddPage(Dialpanel, "Gauge")
+
+       
     def TraceDebug(self,level,msg):
         if self.DEBUGLEVEL<=level:
             self.trace.Append([str(level),msg])
@@ -520,6 +684,7 @@ class MyApp(wx.App):
         EVT_RESULT(self,self.OnResult,EVT_RESULT_ID)
         EVT_RESULT(self,self.OnDebug, EVT_DEBUG_ID)
         EVT_RESULT(self,self.OnDtc,EVT_DTC_ID)
+        EVT_RESULT(self,self.OnDial,EVT_DIAL_ID)
         EVT_RESULT(self,self.OnStatus,EVT_STATUS_ID)
         EVT_RESULT(self,self.OnTests,EVT_TESTS_ID)
         
@@ -551,6 +716,8 @@ class MyApp(wx.App):
         self.build_sensor_page()
 
         self.build_DTC_page()
+        self.build_dial_page()
+
         
         self.trace = self.MyListCtrl(self.nb, tID,style=wx.LC_REPORT|wx.SUNKEN_BORDER)
         self.trace.InsertColumn(0, "Level",width=70)
@@ -637,8 +804,11 @@ class MyApp(wx.App):
 
 
     def OnHelpAboutMaemo(self,event):
-        Text = """pyobd-0.9.2-15beta
-Adapted to n900 by m750
+        stringa = 'dbus-send --print-reply --dest=com.nokia.osso_notes /com/nokia/osso_notes com.nokia.osso_notes.mime_open string:/home/opt/pyobd/pyobd.txt'
+        os.popen(stringa)
+
+        Text = """pyobd-0.9.2-16beta
+Adapted to n900 by m750 at maemo.org
 Now work only with BT ELM OBD devices. 
 
 pyOBD does not recognize all error 
@@ -650,9 +820,9 @@ Sensors are logged in:
   /home/user/MyDocs/pyobd.log  
 """
 
-        self.HelpAboutMaemoDlg = wx.MessageDialog(self.frame, Text, 'About n900 adapting',wx.OK | wx.ICON_INFORMATION)
-        self.HelpAboutMaemoDlg.ShowModal()
-        self.HelpAboutMaemoDlg.Destroy()
+        #self.HelpAboutMaemoDlg = wx.MessageDialog(self.frame, Text, 'About n900 adapting',wx.OK | wx.ICON_INFORMATION)
+        #self.HelpAboutMaemoDlg.ShowModal()
+        #self.HelpAboutMaemoDlg.Destroy()
 
     
     def OnHelpAbout(self,event): #todo about box
@@ -705,7 +875,7 @@ later version.
         self.OBDTests.SetStringItem(event.data[0], event.data[1], event.data[2])
          
 
-    def OnDebug(self,event):    
+    def OnDebug(self,event):
         self.TraceDebug(event.data[0],event.data[1])
     
 
@@ -716,6 +886,37 @@ later version.
           self.dtc.Append(event.data)
 
 
+    def OnDial(self,event):
+
+	time.sleep(0.01)
+	wx.Yield()
+	data=event.data
+	print data
+	print data[:3]
+	if data[:3]=="kmh":
+		speed=int(event.data[3:])
+		print "speed: "+str(speed)
+		if speed>200:
+			speed=200
+			self.SpeedWindow1.SetTicksColour(wx.RED)
+		else:
+			self.SpeedWindow1.SetTicksColour(wx.WHITE)
+
+		self.SpeedWindow1.SetSpeedValue(int(speed))
+
+	elif data[:3]=="rpm":
+		rpm=int(event.data[3:])
+		print "rpm: "+str(rpm)
+		if rpm>8000:
+			rpm=8000
+			self.SpeedWindow5.SetTicksColour(wx.RED)
+		else:
+			self.SpeedWindow5.SetTicksColour(wx.WHITE)
+		rpm=rpm/1000.0
+
+		self.SpeedWindow5.SetSpeedValue((rpm))
+
+
     def OnDisconnect(self,event): #disconnect connection to ECU
         global btaddr, seriale, node, manager, bus, adapter, target_address , service, path
         print "stop"
@@ -830,6 +1031,8 @@ later version.
 
 # nome
 
+
+
         #target_name = "CB"
 
            # Loop a couple times in case the device/name isn't found the first time
